@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -376,7 +376,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def list_instances(
         self,
-        request: cloud_redis.ListInstancesRequest = None,
+        request: Union[cloud_redis.ListInstancesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -395,7 +395,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         are aggregated.
 
         Args:
-            request (google.cloud.redis_v1.types.ListInstancesRequest):
+            request (Union[google.cloud.redis_v1.types.ListInstancesRequest, dict]):
                 The request object. Request for
                 [ListInstances][google.cloud.redis.v1.CloudRedis.ListInstances].
             parent (str):
@@ -467,7 +467,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def get_instance(
         self,
-        request: cloud_redis.GetInstanceRequest = None,
+        request: Union[cloud_redis.GetInstanceRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -477,7 +477,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         r"""Gets the details of a specific Redis instance.
 
         Args:
-            request (google.cloud.redis_v1.types.GetInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.GetInstanceRequest, dict]):
                 The request object. Request for
                 [GetInstance][google.cloud.redis.v1.CloudRedis.GetInstance].
             name (str):
@@ -537,7 +537,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def create_instance(
         self,
-        request: cloud_redis.CreateInstanceRequest = None,
+        request: Union[cloud_redis.CreateInstanceRequest, dict] = None,
         *,
         parent: str = None,
         instance_id: str = None,
@@ -562,7 +562,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1.types.CreateInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.CreateInstanceRequest, dict]):
                 The request object. Request for
                 [CreateInstance][google.cloud.redis.v1.CloudRedis.CreateInstance].
             parent (str):
@@ -659,7 +659,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def update_instance(
         self,
-        request: cloud_redis.UpdateInstanceRequest = None,
+        request: Union[cloud_redis.UpdateInstanceRequest, dict] = None,
         *,
         update_mask: field_mask_pb2.FieldMask = None,
         instance: cloud_redis.Instance = None,
@@ -675,7 +675,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1.types.UpdateInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.UpdateInstanceRequest, dict]):
                 The request object. Request for
                 [UpdateInstance][google.cloud.redis.v1.CloudRedis.UpdateInstance].
             update_mask (google.protobuf.field_mask_pb2.FieldMask):
@@ -765,7 +765,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def upgrade_instance(
         self,
-        request: cloud_redis.UpgradeInstanceRequest = None,
+        request: Union[cloud_redis.UpgradeInstanceRequest, dict] = None,
         *,
         name: str = None,
         redis_version: str = None,
@@ -777,7 +777,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         specified in the request.
 
         Args:
-            request (google.cloud.redis_v1.types.UpgradeInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.UpgradeInstanceRequest, dict]):
                 The request object. Request for
                 [UpgradeInstance][google.cloud.redis.v1.CloudRedis.UpgradeInstance].
             name (str):
@@ -859,7 +859,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def import_instance(
         self,
-        request: cloud_redis.ImportInstanceRequest = None,
+        request: Union[cloud_redis.ImportInstanceRequest, dict] = None,
         *,
         name: str = None,
         input_config: cloud_redis.InputConfig = None,
@@ -878,7 +878,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1.types.ImportInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.ImportInstanceRequest, dict]):
                 The request object. Request for
                 [Import][google.cloud.redis.v1.CloudRedis.ImportInstance].
             name (str):
@@ -960,7 +960,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def export_instance(
         self,
-        request: cloud_redis.ExportInstanceRequest = None,
+        request: Union[cloud_redis.ExportInstanceRequest, dict] = None,
         *,
         name: str = None,
         output_config: cloud_redis.OutputConfig = None,
@@ -975,7 +975,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1.types.ExportInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.ExportInstanceRequest, dict]):
                 The request object. Request for
                 [Export][google.cloud.redis.v1.CloudRedis.ExportInstance].
             name (str):
@@ -1057,7 +1057,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def failover_instance(
         self,
-        request: cloud_redis.FailoverInstanceRequest = None,
+        request: Union[cloud_redis.FailoverInstanceRequest, dict] = None,
         *,
         name: str = None,
         data_protection_mode: cloud_redis.FailoverInstanceRequest.DataProtectionMode = None,
@@ -1070,7 +1070,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         Memorystore for Redis instance.
 
         Args:
-            request (google.cloud.redis_v1.types.FailoverInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.FailoverInstanceRequest, dict]):
                 The request object. Request for
                 [Failover][google.cloud.redis.v1.CloudRedis.FailoverInstance].
             name (str):
@@ -1153,7 +1153,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def delete_instance(
         self,
-        request: cloud_redis.DeleteInstanceRequest = None,
+        request: Union[cloud_redis.DeleteInstanceRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1164,7 +1164,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         serving and data is deleted.
 
         Args:
-            request (google.cloud.redis_v1.types.DeleteInstanceRequest):
+            request (Union[google.cloud.redis_v1.types.DeleteInstanceRequest, dict]):
                 The request object. Request for
                 [DeleteInstance][google.cloud.redis.v1.CloudRedis.DeleteInstance].
             name (str):
